@@ -18,13 +18,17 @@
 .onLoad = function(libname, pkgname)
 {
     loadRcppModules(direct = FALSE)
+}
+
+.onAttach = function(libname, pkgname)
+{
     temp = packageDescription("ngspatial")
     msg = paste(temp$Package, ": ", temp$Title, "\n", "Version ", temp$Version,
                 " created on ", temp$Date, ".\n", sep = "")
-    msg = paste(msg, "copyright (c) 2012, John Hughes, University of Minnesota\n",
+    msg = paste(msg, "copyright (c) 2013, John Hughes, University of Minnesota\n",
 "                    Xiaohui Cui, University of Minnesota\n",
                 sep = "")
     msg = paste(msg, 'For citation information, type citation("ngspatial").\n', sep = "")
-    msg = paste(msg, 'Type help("ngspatial-package") to get started.\n', sep = "")
+    msg = paste(msg, 'Type help(package = ngspatial) to get started.\n', sep = "")
     packageStartupMessage(msg)
 }
